pub struct RandomnessConfig {
pub max_partial_sigs_rounds_ahead: Option<u64>,
pub max_partial_sigs_concurrent_sends: Option<usize>,
pub partial_signature_retry_interval_ms: Option<u64>,
pub mailbox_capacity: Option<usize>,
pub send_partial_signatures_inflight_limit: Option<usize>,
pub max_ignored_peer_weight_factor: Option<f64>,
}Fields
max_partial_sigs_rounds_ahead: Option<u64>Maximum number of rounds ahead of our most recent completed round for which we should accept partial signatures from other validators.
If unspecified, this will default to 50.
max_partial_sigs_concurrent_sends: Option<usize>Maximum number of rounds for which partial signatures should be concurrently sent.
If unspecified, this will default to 20.
partial_signature_retry_interval_ms: Option<u64>Interval at which to retry sending partial signatures until the round is complete.
If unspecified, this will default to 5,000 milliseconds.
mailbox_capacity: Option<usize>Size of the Randomness actor’s mailbox. This should be set large enough to never overflow unless a bug is encountered.
If unspecified, this will default to 1,000,000.
send_partial_signatures_inflight_limit: Option<usize>Per-peer inflight limit for the SendPartialSignatures RPC.
If unspecified, this will default to 20.
max_ignored_peer_weight_factor: Option<f64>Maximum proportion of total peer weight to ignore in case of byzantine behavior.
If unspecified, this will default to 0.2.
Implementations
Sourceimpl RandomnessConfig
impl RandomnessConfig
pub fn max_partial_sigs_rounds_ahead(&self) -> u64
pub fn max_partial_sigs_concurrent_sends(&self) -> usize
pub fn partial_signature_retry_interval(&self) -> Duration
pub fn mailbox_capacity(&self) -> usize
pub fn send_partial_signatures_inflight_limit(&self) -> usize
pub fn max_ignored_peer_weight_factor(&self) -> f64